@@ -300,7 +300,8 @@ class ADObject(ADBase):
             pyadutils.pass_up_com_exception(excpt)
         new_dn = ','.join((self.prefixed_cn,new_ou_object.dn))
         time.sleep(.5)
-        self.__ads_path = pyadutils.generate_ads_path(new_dn, 'LDAP', self.default_ldap_server, self.default_ldap_port)
+        self.__ads_path = pyadutils.generate_ads_path(new_dn, 'LDAP', 
+                self.default_ldap_server, self.default_ldap_port)
         self._ldap_adsi_obj = _adsi_provider.getObject('',self.__ads_path)
         self.__distinguished_name = self.get_attribute('distinguishedName',False)
     
@@ -316,7 +317,8 @@ class ADObject(ADBase):
         try:
             if self.type in ('user', 'computer', 'group') and set_sAMAccountName:
                 self._ldap_adsi_obj.Put('sAMAccountName', new_name)
-            parent._ldap_adsi_obj.MoveHere(('LDAP://'+self.dn), pcn)
+            parent._ldap_adsi_obj.MoveHere(('LDAP://' + self.dn), pcn)
+            time.sleep(.5)
             self._ldap_adsi_obj.GetInfoEx(("distinguishedName", "cn"), 0)
             self.__distinguishedName = self.get_attribute('distinguishedName', False)
         except pywintypes.com_error, excpt:
